/*
 * File: CreateGrayscaleImage.js
 * -----------------------------
 * This program converts a color image to grayscale.
 */

"use strict";

/* Constants */

const GWINDOW_WIDTH = 500;
const GWINDOW_HEIGHT = 300;

/* Main program */

function CreateGrayscaleImage() {
   let selectImage = function(dataURL) {
      let colorImage = GImage(dataURL);
      let processImage = function() {
         let grayscaleImage = createGrayscaleImage(colorImage);
         let placeImages = function() {
            let gw = GWindow(GWINDOW_WIDTH, GWINDOW_HEIGHT);
            let xLeft = (gw.getWidth() - 2 * colorImage.getWidth()) / 3;
            let xRight = gw.getWidth() - colorImage.getWidth() - xLeft;
            let y = (gw.getHeight() - colorImage.getHeight()) / 2;
            gw.add(colorImage, xLeft, y);
            gw.add(grayscaleImage, xRight, y);
         };
         grayscaleImage.addEventListener("load", placeImages);
      };
      colorImage.addEventListener("load", processImage);
   };
   JSFileChooser.chooseDataFile(selectImage);
}

/*
 * Takes a GImage and returns a new GImage in which all pixels have been
 * converted to grayscale.
 */
function createGrayscaleImage(image) {
   return GImage(image.getPixelArray()); // placeholder
}

/*
 * Returns the luminance of a pixel, which is computed from its red,
 * green, and blue components using the formula established by the
 * committee responsible for television standards in the United States.
 */
function luminance(pixel) {
   let r = GImage.getRed(pixel);
   let g = GImage.getGreen(pixel);
   let b = GImage.getBlue(pixel);
   return Math.round(0.299 * r + 0.587 * g + 0.114 * b);
}
